@@ -1,17 +1,17 @@
 #!/usr/bin/python3
 """Build a trivial program using the drpm library."""
 
+from __future__ import annotations
+
 import argparse
 import dataclasses
 import os
 import pathlib
 import shlex
-import subprocess
+import subprocess  # noqa: S404
 import sys
 import tempfile
 
-from typing import Dict
-
 
 EXPECTED = [
     "make standard",
@@ -32,7 +32,7 @@ class Config:
     source: pathlib.Path
     testdir: pathlib.Path
 
-    env: Dict[str, str]
+    env: dict[str, str]
 
     tempd: pathlib.Path
     obj: pathlib.Path
@@ -42,36 +42,49 @@ class Config:
 def do_compile(cfg: Config) -> None:
     """Compile the test program."""
     print("Fetching the C compiler flags for drpm")
-    cflags = subprocess.check_output(
-        ["pkg-config", "--cflags", "drpm"], encoding="UTF-8", shell=False, env=cfg.env
+    cflags = subprocess.check_output(  # noqa: S603
+        ["pkg-config", "--cflags", "drpm"],  # noqa: S607
+        encoding="UTF-8",
+        shell=False,
+        env=cfg.env,
     ).rstrip("\r\n")
     if "\r" in cflags or "\n" in cflags:
         sys.exit(f"`pkg-config --cflags drpm` returned {cflags!r}")
 
     if cfg.obj.exists():
         sys.exit(f"Did not expect {cfg.obj} to exist")
-    cmd = (
-        ["cc", "-c", "-o", str(cfg.obj), "-Wall", "-W", "-Wextra", "-Werror"]
-        + shlex.split(cflags)
-        + [str(cfg.source)]
-    )
+    cmd = [
+        "cc",
+        "-c",
+        "-o",
+        str(cfg.obj),
+        "-Wall",
+        "-W",
+        "-Wextra",
+        "-Werror",
+        *shlex.split(cflags),
+        str(cfg.source),
+    ]
     print(f"Running {cmd!r}")
-    subprocess.check_call(cmd, shell=False, env=cfg.env)
+    subprocess.check_call(cmd, shell=False, env=cfg.env)  # noqa: S603
     if not cfg.obj.is_file():
         sys.exit(f"{cmd!r} did not create the {cfg.obj} file")
 
     print("Fetching the C linker flags and libraries for drpm")
-    libs = subprocess.check_output(
-        ["pkg-config", "--libs", "drpm"], encoding="UTF-8", shell=False, env=cfg.env
+    libs = subprocess.check_output(  # noqa: S603
+        ["pkg-config", "--libs", "drpm"],  # noqa: S607
+        encoding="UTF-8",
+        shell=False,
+        env=cfg.env,
     ).rstrip("\r\n")
     if "\r" in libs or "\n" in libs:
         sys.exit(f"`pkg-config --libs drpm` returned {libs!r}")
 
     if cfg.program.exists():
         sys.exit(f"Did not expect {cfg.program} to exist")
-    cmd = ["cc", "-o", str(cfg.program), str(cfg.obj)] + shlex.split(libs)
+    cmd = ["cc", "-o", str(cfg.program), str(cfg.obj), *shlex.split(libs)]
     print(f"Running {cmd!r}")
-    subprocess.check_call(cmd, shell=False, env=cfg.env)
+    subprocess.check_call(cmd, shell=False, env=cfg.env)  # noqa: S603
     if not cfg.program.is_file():
         sys.exit(f"{cmd!r} did not create the {cfg.program} file")
     if not os.access(cfg.program, os.X_OK):
@@ -129,8 +142,11 @@ def do_run(cfg: Config) -> None:
         cfg.tempd,
     ]
     print(f"Running {command!r}")
-    lines = subprocess.check_output(
-        command, encoding="UTF-8", shell=False, env=cfg.env
+    lines = subprocess.check_output(  # noqa: S603
+        command,
+        encoding="UTF-8",
+        shell=False,
+        env=cfg.env,
     ).splitlines()
     print(f"Got {lines!r}")
 
